==> apache-inlong-1.4.0-src.tar.gz: apache-inlong-1.4.0/inlong-sdk/sdk-common/src/main/java/org/apache/inlong/sdk/commons/admin/PropertiesConfigurationProvider.java <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.inlong.sdk.commons.admin;

import java.util.HashMap;
import java.util.Map;

import org.apache.flume.conf.FlumeConfiguration;
import org.apache.flume.node.AbstractConfigurationProvider;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

/**
 * PropertiesConfigurationProvider
 */
public class PropertiesConfigurationProvider extends
        AbstractConfigurationProvider {

    public static final Logger LOG = LoggerFactory.getLogger(PropertiesConfigurationProvider.class);

    private final Map<String, String> flumeConf;

    /**
     * PropertiesConfigurationProvider
     * 
     * @param rootName
     * @param flumeConf
     */
    public PropertiesConfigurationProvider(String rootName, Map<String, String> flumeConf) {
        super(rootName);
        this.flumeConf = flumeConf;
    }

    /**
     * getFlumeConfiguration
     * 
     * @return
     */
    @Override
    public FlumeConfiguration getFlumeConfiguration() {
        try {
            return new FlumeConfiguration(flumeConf);
        } catch (Exception e) {
            LOG.error("exception catch:" + e.getMessage(), e);
        }
        return new FlumeConfiguration(new HashMap<String, String>());
    }
}

==> apache-inlong-1.7.0-src.tar.gz: apache-inlong-1.7.0/inlong-sdk/sdk-common/src/main/java/org/apache/inlong/sdk/commons/admin/PropertiesConfigurationProvider.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements. See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.inlong.sdk.commons.admin;

import java.util.HashMap;
import java.util.Map;

import org.apache.flume.conf.FlumeConfiguration;
import org.apache.flume.node.AbstractConfigurationProvider;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

/**
 * PropertiesConfigurationProvider
 */
public class PropertiesConfigurationProvider
        extends
            AbstractConfigurationProvider {

    public static final Logger LOG = LoggerFactory.getLogger(PropertiesConfigurationProvider.class);

    private final Map<String, String> flumeConf;

    /**
     * PropertiesConfigurationProvider
     * 
     * @param rootName
     * @param flumeConf
     */
    public PropertiesConfigurationProvider(String rootName, Map<String, String> flumeConf) {
        super(rootName);
        this.flumeConf = flumeConf;
    }

    /**
     * getFlumeConfiguration
     * 
     * @return
     */
    @Override
    public FlumeConfiguration getFlumeConfiguration() {
        try {
            return new FlumeConfiguration(flumeConf);
        } catch (Exception e) {
            LOG.error("exception catch:" + e.getMessage(), e);
        }
        return new FlumeConfiguration(new HashMap<String, String>());
    }
}
